django-mssql-backend-aad
========================

*django-mssql-backend-aad* is a fork of
`django-mssql-backend <https://pypi.org/project/django-mssql-backend/>`__ 
with backported changes from `django-azure-sql-backend <https://github.com/langholz/django-azure-sql-backend>`__

Dependencies
------------

-  Django 2.2 or newer
-  pyodbc 3.0 or newer
-  msal 1.5.1 or newer

Installation
------------

For usage and installation instructions, please refer to:
- https://pypi.org/project/django-mssql-backend 
- https://github.com/langholz/django-azure-sql-backend
